@@ -620,6 +620,10 @@ class Image(EMObject):
         filePaths.add(self.getFileName())
         return filePaths
 
+    def setMRCSamplingRate(self):
+        """ Sets the sampling rate to the mrc file represented by this image"""
+        from pwem.convert.headers import setMRCSamplingRate
+        setMRCSamplingRate(self.getFileName(), self.getSamplingRate())
 
 class Micrograph(Image):
     """ Represents an EM Micrograph object """
@@ -740,6 +744,11 @@ class Volume(Image):
     def setHalfMaps(self, listFileNames):
         return self._halfMapFilenames.set(listFileNames)
 
+    def fixMRCVolume(self):
+        """ Fixes the header of the mrc file pointed by this object """
+        from pwem.convert.headers import fixVolume
+        fixVolume(self.getFileName())
+
     def __str__(self):
         """ returns string representation adding halves info to base image.__str__"""
         imgStr = super().__str__()
@@ -828,6 +837,44 @@ class Sequence(EMObject):
     def getIsAminoacids(self):
         return self._isAminoacids
 
+    def importFromFile(self, seqFileName, isAmino=True):
+        '''Fills the sequence attributes from the FIRST sequence found in the specified file'''
+        import pwem.convert as emconv
+        seqHandler = emconv.SequenceHandler()
+        seqDic = seqHandler.readSequenceFromFile(seqFileName, type=None, isAmino=isAmino)
+        self.setSequence(seqDic['sequence']), self.setId(seqDic['seqID'])
+        self.setName(seqDic['name']), self.setDescription(seqDic['description'])
+        self._alphabet.set(Integer(seqDic['alphabet']))
+        self._isAminoacids.set(Boolean(seqDic['isAminoacids']))
+
+    def exportToFile(self, seqFileName):
+        '''Exports the sequence to the specified file'''
+        import pwem.convert as emconv
+        seqHandler = emconv.SequenceHandler(self.getSequence(),
+                                            isAminoacid=self.getIsAminoacids())
+        # retrieving  args from scipion object
+        seqID = self.getId() if self.getId() is not None else 'seqID'
+        seqName = self.getSeqName() if self.getSeqName() is not None else 'seqName'
+        seqDescription = self.getDescription() if self.getDescription() is not None else ''
+        seqHandler.saveFile(seqFileName, seqID,
+                            name=seqName, seqDescription=seqDescription,
+                            type=None)
+
+    def appendToFile(self, seqFileName):
+        '''Exports the sequence to the specified file. If it already exists,
+        the sequence is appended to the ones in the file'''
+        import pwem.convert as emconv
+        seqHandler = emconv.SequenceHandler(self.getSequence(),
+                                            isAminoacid=self.getIsAminoacids())
+        # retrieving  args from scipion object
+        seqID = self.getId() if self.getId() is not None else 'seqID'
+        seqName = self.getSeqName() if self.getSeqName() is not None else 'seqName'
+        seqDescription = self.getDescription() if self.getDescription() is not None else ''
+        seqHandler.appendFile(seqFileName, seqID,
+                            name=seqName, seqDescription=seqDescription,
+                            type=None)
+
+
     def __str__(self):
         return "Sequence (name = {})\n".format(self.getSeqName())
 
@@ -977,6 +1024,8 @@ class EMSet(Set, EMObject):
         if suffix:
             fn += '_%s' % suffix
 
+        if ext and ext[0] == '.':
+            ext = ext[1:]
         fn += '.%s' % (ext or 'sqlite')
 
         setPath = os.path.join(outputPath, fn)
@@ -1413,6 +1462,22 @@ class SetOfSequences(EMSet):
     """Set containing Sequence items."""
     ITEM_TYPE = Sequence
 
+    def exportToFile(self, seqFileName):
+        '''Writes the sequences in the set in the specified file'''
+        for sequence in self:
+            sequence.appendToFile(seqFileName)
+
+    def importFromFile(self, seqFileName, isAmino=True):
+        '''Appends elements to the set from sequences found in the specified file'''
+        import pwem.convert as emconv
+        seqHandler = emconv.SequenceHandler()
+        seqsDic = seqHandler.readSequencesFromFile(seqFileName, type=None, isAmino=isAmino)
+        for seqDic in seqsDic:
+            newSeq = Sequence(sequence=seqDic['sequence'], id=seqDic['seqID'],
+                              name=seqDic['name'], description=seqDic['description'],
+                              alphabet=seqDic['alphabet'], isAminoacids=seqDic['isAminoacids'])
+            self.append(newSeq)
+
 
 class Coordinate(EMObject):
     """This class holds the (x,y) position and other information
@@ -2342,6 +2407,21 @@ class FSC(EMObject):
         self._x.set(xData)
         self._y.set(yData)
 
+    def calculateResolution(self, threshold=0.143):
+        """
+        Calculate the FSC resolution value
+        """
+        dataLength = len(self._x)
+        for i in range(dataLength):
+            if float(self._y[i]) < threshold or i == dataLength-1:
+                above_res = float(self._x[i-1])
+                above_fsc = float(self._y[i-1])
+                bellow_res = float(self._x[i])
+                bellow_fsc = float(self._y[i])
+                break
+        resolution = bellow_res - ((threshold-bellow_fsc)/(above_fsc-bellow_fsc) * (bellow_res-above_res))
+        return "{0:.1f}".format(1/resolution)
+
 
 class SetOfFSCs(EMSet):
     """Represents a set of FSCs"""
