@@ -140,15 +140,15 @@ class ProtUnionSet(ProtSets):
                            'but we really want to insert as new items in the '
                            'output. \n'
                            'On the other hand, items originated in a previous common '
-                           'protocol (above in the workflow) might have identical items'
+                           'protocol (above in the workflow) might have identical items '
                            'and you would like to remove them. '
                            'Therefore, set this option to *Yes* to remove duplicates and keep only '
-                           'one copy of the item. (the first occurrence)')
+                           'one copy of the item (the first occurrence).')
         form.addParam('renumber', pwprot.params.BooleanParam, default=False,
                       expertLevel=pwprot.LEVEL_ADVANCED,
                       label="Force new ids",
-                      help='Make an automatic renumbering of the ids, so all '
-                           'new objects will not be associated to the old ones.')
+                      help='Perform an automatic renumbering of ids to ensure all objects have unique ids. '
+                           'This will mean new objects will not be associated to the old ones.')
 
         # TODO: See what kind of restrictions we add,
         # like "All sets should have the same sampling rate."
@@ -575,7 +575,7 @@ class ProtSubSet(ProtSets):
                      progress.update(i+1)
                 if i == chosen[j]:
                      j += 1
-                     outputSet.append(elem)
+                     self._append(outputSet, elem)
                      if j >= nElements:
                           break # all needed elements have been appended
             if doProgressBar:
